package com.jtxt.demo.util;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.time.LocalDate;
import java.time.ZoneId;
import java.time.format.DateTimeFormatter;
import java.time.temporal.ChronoUnit;
import java.time.temporal.WeekFields;
import java.util.Date;
import java.util.Locale;

public class Utils {
    public static final ZoneId CHINA_ZONE = ZoneId.of("Asia/Shanghai");
    public static String getTodayTag() {
        DateTimeFormatter dtf = DateTimeFormatter.ofPattern("uuuuMMdd");
        LocalDate localDate = LocalDate.now(CHINA_ZONE);
        return dtf.format(localDate);
    }

    public static String getYesterdayTag() {
        DateTimeFormatter dtf = DateTimeFormatter.ofPattern("uuuuMMdd");
        LocalDate localDate = LocalDate.now(CHINA_ZONE).minusDays(1);
        return dtf.format(localDate);
    }

    public static boolean isValidDateTag(String tag) {
        DateTimeFormatter dtf = DateTimeFormatter.ofPattern("uuuuMMdd");
        try {
            LocalDate dateTag = LocalDate.parse(tag, dtf);
            LocalDate today = LocalDate.now(CHINA_ZONE);

            //calculating number of days in between
            long noOfDaysBetween = ChronoUnit.DAYS.between(dateTag, today);
            if (dateTag.isBefore(today) && noOfDaysBetween > 1) {
                return false;
            }
        } catch (Exception e) {
            return false;
        }
        return true;
    }

    // return "2021Week2" to indicate that the second week of 2021.
    public static String getWeekTag() {
        return getYear() + "Week" + getWeekNum();
    }



    public static int getYear() {
        LocalDate localDate = LocalDate.now(CHINA_ZONE);
        return localDate.getYear();
    }

    public static int getWeekNum() {
        LocalDate localDate = LocalDate.now(CHINA_ZONE);
        return localDate.get(WeekFields.of(Locale.getDefault()).weekOfWeekBasedYear());
    }
}
